@@ -1,8 +1,9 @@
 """Services for the `lilypad` server."""
 
 from .api_keys import APIKeyService
-from .device_codes import DeviceCodeService
 from .generations import GenerationService
+from .organization_invites import OrganizationInviteService
+from .organizations import OrganizationService
 from .projects import ProjectService
 from .prompts import PromptService
 from .spans import SpanService
